@@ -20,8 +20,6 @@ class DBClient:
         self.db_name = db_name
 
     def connect(self):
-        t = datetime.datetime.now()
-        print(f"{t}: trying to establish DB connection")
         self._connector = mysql.connector.connect(
             host=self.db_server,
             user=self.db_user,
@@ -29,7 +27,7 @@ class DBClient:
             database=self.db_name,
             connection_timeout=10)
         self._cursor = self._connector.cursor()
-        print(f"{t}: connected")
+        print(f"{self._connector.connection_id}: connection established")
 
     def execute(self, SQL_command: str, params=()) -> None:
         try:
@@ -55,9 +53,12 @@ class DBClient:
     def close_connection(self):
         try:
             self._cursor.close()
+            print(f"{self._connector.connection_id}: cursor closed")
         except Exception:
             traceback.print_exc()
         try:
+            cid = self._connector.connection_id
             self._connector.close()
+            print(f"{cid}: connection closed")
         except Exception:
             traceback.print_exc()
